@@ -27,7 +27,7 @@ import java.util.Properties;
 import org.jboss.as.clustering.controller.CommonRequirement;
 import org.jboss.as.clustering.controller.CommonUnaryRequirement;
 import org.jboss.as.clustering.jgroups.subsystem.JGroupsSubsystemResourceDefinition;
-import org.jboss.as.clustering.subsystem.ClusteringSubsystemTest;
+import org.jboss.as.subsystem.test.AbstractSubsystemSchemaTest;
 import org.jboss.as.subsystem.test.AdditionalInitialization;
 import org.jboss.as.subsystem.test.KernelServices;
 import org.jboss.dmr.ModelNode;
@@ -47,20 +47,25 @@ import org.wildfly.clustering.jgroups.spi.JGroupsDefaultRequirement;
  * @author Richard Achmatowicz (c) 2013 Red Hat Inc.
  */
 @RunWith(value = Parameterized.class)
-public class InfinispanSubsystemTestCase extends ClusteringSubsystemTest<InfinispanSchema> {
+public class InfinispanSubsystemTestCase extends AbstractSubsystemSchemaTest<InfinispanSubsystemSchema> {
 
     @Parameters
-    public static Iterable<InfinispanSchema> parameters() {
-        return EnumSet.allOf(InfinispanSchema.class);
+    public static Iterable<InfinispanSubsystemSchema> parameters() {
+        return EnumSet.allOf(InfinispanSubsystemSchema.class);
     }
 
-    private final InfinispanSchema schema;
+    private final InfinispanSubsystemSchema schema;
 
-    public InfinispanSubsystemTestCase(InfinispanSchema schema) {
-        super(InfinispanExtension.SUBSYSTEM_NAME, new InfinispanExtension(), schema, "subsystem-infinispan-%d_%d.xml", "schema/jboss-as-infinispan_%d_%d.xsd");
+    public InfinispanSubsystemTestCase(InfinispanSubsystemSchema schema) {
+        super(InfinispanExtension.SUBSYSTEM_NAME, new InfinispanExtension(), schema, InfinispanSubsystemSchema.CURRENT);
         this.schema = schema;
     }
 
+    @Override
+    protected String getSubsystemXsdPathPattern() {
+        return "schema/jboss-as-%s_%d_%d.xsd";
+    }
+
     @Override
     protected AdditionalInitialization createAdditionalInitialization() {
         return new InfinispanSubsystemInitialization()
@@ -73,11 +78,6 @@ public class InfinispanSubsystemTestCase extends ClusteringSubsystemTest<Infinis
                 ;
     }
 
-    @Override
-    public void testSchemaOfSubsystemTemplates() throws Exception {
-        // Skip
-    }
-
     @Override
     protected void compare(ModelNode model1, ModelNode model2) {
         purgeJGroupsModel(model1);
@@ -100,7 +100,7 @@ public class InfinispanSubsystemTestCase extends ClusteringSubsystemTest<Infinis
     protected KernelServices standardSubsystemTest(String configId, String configIdResolvedModel, boolean compareXml, AdditionalInitialization additionalInit) throws Exception {
         KernelServices services = super.standardSubsystemTest(configId, configIdResolvedModel, compareXml, additionalInit);
 
-        if (!this.schema.since(InfinispanSchema.VERSION_1_5)) {
+        if (!this.schema.since(InfinispanSubsystemSchema.VERSION_1_5)) {
             ModelNode model = services.readWholeModel();
 
             Assert.assertTrue(model.get(InfinispanSubsystemResourceDefinition.PATH.getKey()).hasDefined(InfinispanSubsystemResourceDefinition.PATH.getValue()));
