@@ -24,6 +24,10 @@ package org.wildfly.clustering.marshalling.protostream;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
+import java.util.IdentityHashMap;
+import java.util.Map;
+import java.util.OptionalInt;
+import java.util.function.Function;
 
 import org.infinispan.protostream.ProtobufTagMarshaller.WriteContext;
 import org.infinispan.protostream.TagWriter;
@@ -33,15 +37,46 @@ import org.infinispan.protostream.descriptors.WireType;
  * Delegates most {@link ProtoStreamWriter} operations to a {@link TagWriter}.
  * @author Paul Ferraro
  */
-public abstract class AbstractProtoStreamWriter extends DefaultProtoStreamOperation implements ProtoStreamWriter, WriteContext {
+public abstract class AbstractProtoStreamWriter extends AbstractProtoStreamOperation implements ProtoStreamWriter, WriteContext {
+
+    interface ProtoStreamWriterContext extends ProtoStreamOperation.Context {
+        /**
+         * Returns an existing reference to the specified object, if one exists.
+         * @param object an object whose may already have been referenced
+         * @return a reference for the specified object, or null, if no reference yet exists.
+         */
+        Reference getReference(Object object);
+
+        /**
+         * Creates a copy of this writer context.
+         * Used to ensure reference integrity between size and write operations.
+         * @return a copy of this writer context
+         */
+        ProtoStreamWriterContext clone();
+
+        /**
+         * Computes the size of the specified object via the specified function, if not already known
+         * @param object the target object
+         * @param function a function that computes the size of the specified object
+         * @return the computed or cached size
+         */
+        OptionalInt computeSize(Object object, Function<Object, OptionalInt> function);
+    }
 
     private final TagWriter writer;
     private final int depth;
+    private final ProtoStreamWriterContext context;
 
-    protected AbstractProtoStreamWriter(WriteContext context) {
+    protected AbstractProtoStreamWriter(WriteContext context, ProtoStreamWriterContext writerContext) {
         super(context);
         this.writer = context.getWriter();
         this.depth = context.depth();
+        this.context = writerContext;
+    }
+
+    @Override
+    public Context getContext() {
+        return this.context;
     }
 
     @Override
@@ -54,6 +89,16 @@ public abstract class AbstractProtoStreamWriter extends DefaultProtoStreamOperat
         return this.depth;
     }
 
+    @Override
+    public void writeAnyNoTag(Object value) throws IOException {
+        Reference reference = this.context.getReference(value);
+        Any any = new Any((reference != null) ? reference : value);
+        this.writeObjectNoTag(any);
+        if (reference == null) {
+            this.context.record(value);
+        }
+    }
+
     @Override
     public void writeTag(int number, WireType wireType) throws IOException {
         this.writer.writeTag(number, wireType);
@@ -184,4 +229,51 @@ public abstract class AbstractProtoStreamWriter extends DefaultProtoStreamOperat
     public void flush() throws IOException {
         this.writer.flush();
     }
+
+    static class DefaultProtoStreamWriterContext implements ProtoStreamWriterContext, Function<Object, Reference> {
+        private final Map<Object, Reference> references = new IdentityHashMap<>(128);
+        private int reference = 0; // Enumerates object references
+        private final Map<Object, OptionalInt> sizes;
+
+        DefaultProtoStreamWriterContext() {
+            this(new IdentityHashMap<>(128));
+        }
+
+        private DefaultProtoStreamWriterContext(Map<Object, OptionalInt> sizes) {
+            this.sizes = sizes;
+        }
+
+        @Override
+        public void record(Object object) {
+            if (object != null) {
+                this.references.computeIfAbsent(object, this);
+            }
+        }
+
+        @Override
+        public Reference getReference(Object object) {
+            return (object != null) ? this.references.get(object) : null;
+        }
+
+        @Override
+        public Reference apply(Object key) {
+            return new Reference(this.reference++);
+        }
+
+        @Override
+        public ProtoStreamWriterContext clone() {
+            // Share size cache
+            DefaultProtoStreamWriterContext context = new DefaultProtoStreamWriterContext(this.sizes);
+            // Copy references
+            context.references.putAll(this.references);
+            context.reference = this.reference;
+            return context;
+        }
+
+        @Override
+        public OptionalInt computeSize(Object object, Function<Object, OptionalInt> function) {
+            // Don't cache size for internal wrappers, which would otherwise bloat our hashtable
+            return (object instanceof Any) ? function.apply(object) : this.sizes.computeIfAbsent(object, function);
+        }
+    }
 }
