@@ -25,7 +25,7 @@ package org.jboss.as.jpa.config;
 import java.util.HashMap;
 import java.util.Map;
 
-import javax.persistence.EntityManagerFactory;
+import jakarta.persistence.EntityManagerFactory;
 
 import org.jipijapa.plugin.spi.PersistenceUnitMetadata;
 
@@ -136,16 +136,11 @@ public class Configuration {
     public static final String JPA_DEFAULT_PERSISTENCE_UNIT = "wildfly.jpa.default-unit";
 
     /**
-     * defaults to true, if false, persistence unit will not support javax.persistence.spi.ClassTransformer Interface
+     * defaults to true, if false, persistence unit will not support jakarta.persistence.spi.ClassTransformer Interface
      * which means no application class rewriting
      */
     public static final String JPA_CONTAINER_CLASS_TRANSFORMER = "jboss.as.jpa.classtransformer";
 
-    private static final String HIBERNATE_USE_CLASS_ENHANCER = "hibernate.ejb.use_class_enhancer";
-    private static final String HIBERNATE_ENABLE_DIRTY_TRACKING = "hibernate.enhancer.enableDirtyTracking";
-    private static final String HIBERNATE_ENABLE_LAZY_INITIALIZATION = "hibernate.enhancer.enableLazyInitialization";
-    private static final String HIBERNATE_ENABLE_ASSOCIATION_MANAGEMENT = "hibernate.enhancer.enableAssociationManagement";
-
     /**
      * set to false to force a single phase persistence unit bootstrap to be used (default is true
      * which uses two phases to start the persistence unit).
@@ -196,14 +191,59 @@ public class Configuration {
     public static final String HIBERNATE_SEARCH_MODULE = "wildfly.jpa.hibernate.search.module";
 
     /**
-     * name of the Hibernate Search module name
+     * name of the Hibernate Search integrator adaptor module
      */
-    public static final String PROVIDER_MODULE_HIBERNATE_SEARCH = "org.hibernate.search.orm";
+    public static final String HIBERNATE_SEARCH_INTEGRATOR_ADAPTOR_MODULE_NAME = "org.hibernate.search.jipijapa-hibernatesearch";
 
+    /**
+     * name of the Hibernate Search module providing the ORM mapper
+     */
+    public static final String HIBERNATE_SEARCH_MODULE_MAPPER_ORM = "org.hibernate.search.mapper.orm";
+
+    /**
+     * name of the Hibernate Search module providing the outbox-polling coordination strategy
+     */
+    public static final String HIBERNATE_SEARCH_MODULE_MAPPER_ORM_COORDINATION_OUTBOXPOLLING = "org.hibernate.search.mapper.orm.coordination.outboxpolling";
+
+    /**
+     * name of the Hibernate Search module providing the Lucene backend
+     */
+    public static final String HIBERNATE_SEARCH_MODULE_BACKEND_LUCENE = "org.hibernate.search.backend.lucene";
+
+    /**
+     * name of the Hibernate Search module providing the Elasticsearch backend
+     */
+    public static final String HIBERNATE_SEARCH_MODULE_BACKEND_ELASTICSEARCH = "org.hibernate.search.backend.elasticsearch";
+
+    /**
+     * name of the Hibernate Search configuration property allowing to set the backend type
+     */
+    public static final String HIBERNATE_SEARCH_BACKEND_TYPE = "hibernate.search.backend.type";
+
+    /**
+     * The value of the {@link #HIBERNATE_SEARCH_BACKEND_TYPE} property that identifies the use of a Lucene backend.
+     */
+    public static final String HIBERNATE_SEARCH_BACKEND_TYPE_VALUE_LUCENE = "lucene";
+
+    /**
+     * The value of the {@link #HIBERNATE_SEARCH_BACKEND_TYPE} property that identifies the use of an Elasticsearch backend.
+     */
+    public static final String HIBERNATE_SEARCH_BACKEND_TYPE_VALUE_ELASTICSEARCH = "elasticsearch";
+
+    /**
+     * Name of the Hibernate Search configuration property allowing to set the coordination strategy
+     */
+    public static final String HIBERNATE_SEARCH_COORDINATION_STRATEGY = "hibernate.search.coordination.strategy";
+
+    /**
+     * The value of the {@link #HIBERNATE_SEARCH_COORDINATION_STRATEGY} property that identifies the use of an Elasticsearch backend.
+     */
+    public static final String HIBERNATE_SEARCH_COORDINATION_STRATEGY_VALUE_OUTBOX_POLLING = "outbox-polling";
 
     private static final String EE_DEFAULT_DATASOURCE = "java:comp/DefaultDataSource";
     // key = provider class name, value = module name
     private static final Map<String, String> providerClassToModuleName = new HashMap<String, String>();
+    private static final String HIBERNATE = "Hibernate";
 
     static {
         // always choose the default hibernate version for the Hibernate provider class mapping
@@ -237,32 +277,24 @@ public class Configuration {
     /**
      * Determine if class file transformer is needed for the specified persistence unit
      *
-     * if the persistence provider is Hibernate and use_class_enhancer is not true, don't need a class transformer.
-     * for other persistence providers, the transformer is assumed to be needed.
+     * for all persistence providers, the transformer is assumed to be needed unless the application indicates otherwise.
      *
      * @param pu the PU
      * @return true if class file transformer support is needed for pu
      */
     public static boolean needClassFileTransformer(PersistenceUnitMetadata pu) {
-        boolean result = true;
-        String provider = pu.getPersistenceProviderClassName();
-        if (pu.getProperties().containsKey(Configuration.JPA_CONTAINER_CLASS_TRANSFORMER)) {
-            result = Boolean.parseBoolean(pu.getProperties().getProperty(Configuration.JPA_CONTAINER_CLASS_TRANSFORMER));
-        }
-        else if (isHibernateProvider(provider)) {
-            result = (Boolean.TRUE.toString().equals(pu.getProperties().getProperty(HIBERNATE_USE_CLASS_ENHANCER))
-                    || Boolean.TRUE.toString().equals(pu.getProperties().getProperty(HIBERNATE_ENABLE_DIRTY_TRACKING))
-                    || Boolean.TRUE.toString().equals(pu.getProperties().getProperty(HIBERNATE_ENABLE_LAZY_INITIALIZATION))
-                    || Boolean.TRUE.toString().equals(pu.getProperties().getProperty(HIBERNATE_ENABLE_ASSOCIATION_MANAGEMENT)));
-        }
-        return result;
-    }
 
+        if (pu.getProperties().containsKey(Configuration.JPA_CONTAINER_CLASS_TRANSFORMER)) {
+            return Boolean.parseBoolean(pu.getProperties().getProperty(Configuration.JPA_CONTAINER_CLASS_TRANSFORMER));
+        }
+        if (isHibernateProvider(pu.getPersistenceProviderClassName())) {
+            return false;
+        }
+        return true;
+    }
     private static boolean isHibernateProvider(String provider) {
-        return provider == null ||
-                PROVIDER_CLASS_HIBERNATE.equals(provider) ||
-                PROVIDER_CLASS_HIBERNATE_OGM.equals(provider) ||
-                PROVIDER_CLASS_HIBERNATE4_1.equals(provider);
+        // If the persistence provider is not specified (null case), Hibernate ORM will be used as the persistence provider.
+        return provider == null || provider.contains(HIBERNATE);
     }
 
     // key = provider class name, value = adapter module name
