@@ -21,11 +21,9 @@
  */
 package org.wildfly.extension.microprofile.openapi;
 
-import java.io.IOException;
 import java.util.EnumSet;
-import java.util.Locale;
 
-import org.jboss.as.subsystem.test.AbstractSubsystemBaseTest;
+import org.jboss.as.subsystem.test.AbstractSubsystemSchemaTest;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
@@ -35,9 +33,7 @@ import org.junit.runners.Parameterized.Parameters;
  * @author Paul Ferraro
  */
 @RunWith(value = Parameterized.class)
-public class MicroProfileOpenAPISubsystemTestCase extends AbstractSubsystemBaseTest {
-
-    private final MicroProfileOpenAPISubsystemSchema schema;
+public class MicroProfileOpenAPISubsystemTestCase extends AbstractSubsystemSchemaTest<MicroProfileOpenAPISubsystemSchema> {
 
     @Parameters
     public static Iterable<MicroProfileOpenAPISubsystemSchema> parameters() {
@@ -45,17 +41,6 @@ public class MicroProfileOpenAPISubsystemTestCase extends AbstractSubsystemBaseT
     }
 
     public MicroProfileOpenAPISubsystemTestCase(MicroProfileOpenAPISubsystemSchema schema) {
-        super(MicroProfileOpenAPIExtension.SUBSYSTEM_NAME, new MicroProfileOpenAPIExtension());
-        this.schema = schema;
-    }
-
-    @Override
-    protected String getSubsystemXml() throws IOException {
-        return this.readResource(String.format(Locale.ROOT, "%s_%d_%d.xml", this.getMainSubsystemName(), this.schema.getVersion().major(), this.schema.getVersion().minor()));
-    }
-
-    @Override
-    protected String getSubsystemXsdPath() throws IOException {
-        return String.format(Locale.ROOT, "schema/wildfly-%s_%d_%d.xsd", this.getMainSubsystemName(), this.schema.getVersion().major(), this.schema.getVersion().minor());
+        super(MicroProfileOpenAPIExtension.SUBSYSTEM_NAME, new MicroProfileOpenAPIExtension(), schema, MicroProfileOpenAPISubsystemSchema.CURRENT);
     }
 }
\ No newline at end of file
