@@ -22,11 +22,11 @@
 
 package org.jboss.as.test.integration.ejb.stateful.passivation.ejb2;
 
-import javax.ejb.EJBHome;
+import jakarta.ejb.EJBHome;
 
 /**
  * @author Ondrej Chaloupka
  */
 public interface TestPassivationRemoteHome extends EJBHome {
-    TestPassivationRemote create() throws java.rmi.RemoteException, javax.ejb.CreateException;
+    TestPassivationRemote create() throws java.rmi.RemoteException, jakarta.ejb.CreateException;
 }
