@@ -59,7 +59,6 @@ import org.jboss.as.controller.PathAddress;
 import org.jboss.as.controller.client.Operation;
 import org.jboss.as.controller.client.OperationBuilder;
 import org.jboss.as.test.integration.domain.management.util.DomainTestSupport;
-import org.jboss.as.test.integration.domain.mixed.jsf.Bean;
 import org.jboss.as.test.shared.TestSuiteEnvironment;
 import org.jboss.dmr.ModelNode;
 import org.jboss.shrinkwrap.api.ShrinkWrap;
@@ -93,7 +92,6 @@ public abstract class MixedDomainDeploymentTest {
 
     private WebArchive webArchive;
     private WebArchive webArchive2;
-    private WebArchive jsfTestArchive;
     private MixedDomainTestSupport testSupport;
     private File tmpDir;
 
@@ -121,15 +119,6 @@ public abstract class MixedDomainDeploymentTest {
         webArchive.as(ZipExporter.class).exportTo(new File(tmpDir, "archives/" + TEST), true);
         webArchive.as(ExplodedExporter.class).exportExploded(new File(tmpDir, "exploded"));
 
-        //Make the jsf war to test that jsf works on the older slaves that did not have the jsf subsystem
-        jsfTestArchive = ShrinkWrap.create(WebArchive.class, "jsf-test.war");
-        jsfTestArchive.addClass(Bean.class);
-        jsfTestArchive.addAsWebResource("jsf-test/index.html");
-        jsfTestArchive.addAsWebResource("jsf-test/home.xhtml");
-        jsfTestArchive.addAsWebInfResource("jsf-test/WEB-INF/beans.xml");
-        jsfTestArchive.addAsWebInfResource("jsf-test/WEB-INF/faces-config.xml");
-
-
         // Launch the domain
         testSupport = MixedDomainTestSuite.getSupport(this.getClass());
         confirmNoDeployments();
@@ -155,13 +144,13 @@ public abstract class MixedDomainDeploymentTest {
         assertEquals("Deployments are removed from the domain", 0, deploymentList.size());
 
         try {
-            performHttpCall(DomainTestSupport.masterAddress, 8080);
+            performHttpCall(DomainTestSupport.primaryAddress, 8080);
             fail(TEST + " is available on main-one");
         } catch (IOException good) {
             // good
         }
         try {
-            performHttpCall(DomainTestSupport.slaveAddress, 8630);
+            performHttpCall(DomainTestSupport.secondaryAddress, 8630);
             fail(TEST + " is available on other-three");
         } catch (IOException good) {
             // good
@@ -174,9 +163,9 @@ public abstract class MixedDomainDeploymentTest {
         ModelNode content = new ModelNode();
         content.get("url").set(url);
         ModelNode composite = createDeploymentOperation(content, OTHER_SERVER_GROUP_DEPLOYMENT_ADDRESS, MAIN_SERVER_GROUP_DEPLOYMENT_ADDRESS);
-        executeOnMaster(composite);
+        executeOnPrimary(composite);
 
-        performHttpCall(DomainTestSupport.slaveAddress, 8080);
+        performHttpCall(DomainTestSupport.secondaryAddress, 8080);
     }
 
     @Test
@@ -187,9 +176,9 @@ public abstract class MixedDomainDeploymentTest {
         OperationBuilder builder = new OperationBuilder(composite, true);
         builder.addInputStream(webArchive.as(ZipExporter.class).exportAsInputStream());
 
-        executeOnMaster(builder.build());
+        executeOnPrimary(builder.build());
 
-        performHttpCall(DomainTestSupport.slaveAddress, 8080);
+        performHttpCall(DomainTestSupport.secondaryAddress, 8080);
 
     }
 
@@ -199,9 +188,9 @@ public abstract class MixedDomainDeploymentTest {
         content.get("archive").set(true);
         content.get("path").set(new File(tmpDir, "archives/" + TEST).getAbsolutePath());
         ModelNode composite = createDeploymentOperation(content, OTHER_SERVER_GROUP_DEPLOYMENT_ADDRESS, MAIN_SERVER_GROUP_DEPLOYMENT_ADDRESS);
-        executeOnMaster(composite);
+        executeOnPrimary(composite);
 
-        performHttpCall(DomainTestSupport.slaveAddress, 8080);
+        performHttpCall(DomainTestSupport.secondaryAddress, 8080);
     }
 
     @Test
@@ -211,9 +200,9 @@ public abstract class MixedDomainDeploymentTest {
         content.get("path").set(new File(tmpDir, "exploded/" + TEST).getAbsolutePath());
         ModelNode composite = createDeploymentOperation(content, OTHER_SERVER_GROUP_DEPLOYMENT_ADDRESS, MAIN_SERVER_GROUP_DEPLOYMENT_ADDRESS);
 
-        executeOnMaster(composite);
+        executeOnPrimary(composite);
 
-        performHttpCall(DomainTestSupport.slaveAddress, 8080);
+        performHttpCall(DomainTestSupport.secondaryAddress, 8080);
     }
 
     protected boolean supportManagedExplodedDeployment() {
@@ -226,9 +215,9 @@ public abstract class MixedDomainDeploymentTest {
         empty.get(EMPTY).set(true);
         ModelNode composite = createDeploymentOperation(empty, OTHER_SERVER_GROUP_DEPLOYMENT_ADDRESS, MAIN_SERVER_GROUP_DEPLOYMENT_ADDRESS);
         if (supportManagedExplodedDeployment()) {
-            executeOnMaster(composite);
+            executeOnPrimary(composite);
         } else {
-            ModelNode failure = executeForFailureOnMaster(composite);
+            ModelNode failure = executeForFailureOnPrimary(composite);
             assertTrue(failure.toJSONString(true), failure.toJSONString(true).contains("WFLYCTL0421:"));
         }
     }
@@ -268,10 +257,10 @@ public abstract class MixedDomainDeploymentTest {
         builder.addInputStream(tccl.getResourceAsStream("helloWorld/index.html"));
         builder.addInputStream(tccl.getResourceAsStream("helloWorld/index2.html"));
         if (supportManagedExplodedDeployment()) {
-            executeOnMaster(builder.build());
-            performHttpCall(DomainTestSupport.slaveAddress, 8080);
+            executeOnPrimary(builder.build());
+            performHttpCall(DomainTestSupport.secondaryAddress, 8080);
         } else {
-            ModelNode failure = executeForFailureOnMaster(builder.build());
+            ModelNode failure = executeForFailureOnPrimary(builder.build());
             assertTrue(failure.toJSONString(true), failure.toJSONString(true).contains("WFLYCTL0421:"));
         }
     }
@@ -335,41 +324,27 @@ public abstract class MixedDomainDeploymentTest {
         OperationBuilder builder = new OperationBuilder(op, true);
         builder.addInputStream(webArchive.as(ZipExporter.class).exportAsInputStream());
 
-        executeOnMaster(builder.build());
+        executeOnPrimary(builder.build());
 
-        performHttpCall(DomainTestSupport.slaveAddress, 8080);
-    }
-
-    @Test
-    public void testJsfWorks() throws Exception {
-        ModelNode content = new ModelNode();
-        content.get(INPUT_STREAM_INDEX).set(0);
-        //Just be lazy here and deploy the jsf-test.war with the same name as the other deployments we tried
-        ModelNode composite = createDeploymentOperation(content, OTHER_SERVER_GROUP_DEPLOYMENT_ADDRESS, MAIN_SERVER_GROUP_DEPLOYMENT_ADDRESS);
-        OperationBuilder builder = new OperationBuilder(composite, true);
-        builder.addInputStream(jsfTestArchive.as(ZipExporter.class).exportAsInputStream());
-
-        executeOnMaster(builder.build());
-
-        performHttpCall(DomainTestSupport.slaveAddress, 8080, "test/home.jsf", "Bean Works");
+        performHttpCall(DomainTestSupport.secondaryAddress, 8080);
     }
 
     private void redeployTest() throws IOException {
         ModelNode op = createEmptyOperation("redeploy", OTHER_SERVER_GROUP_DEPLOYMENT_ADDRESS);
-        executeOnMaster(op);
+        executeOnPrimary(op);
 
-        performHttpCall(DomainTestSupport.slaveAddress, 8080);
+        performHttpCall(DomainTestSupport.secondaryAddress, 8080);
     }
 
 
     private void undeployTest() throws Exception {
         ModelNode op = createEmptyOperation("undeploy", OTHER_SERVER_GROUP_DEPLOYMENT_ADDRESS);
-        executeOnMaster(op);
+        executeOnPrimary(op);
 
         // Thread.sleep(1000);
 
         try {
-            performHttpCall(DomainTestSupport.slaveAddress, 8080);
+            performHttpCall(DomainTestSupport.secondaryAddress, 8080);
             fail("Webapp still accessible following undeploy");
         } catch (IOException good) {
             // desired result
@@ -396,20 +371,20 @@ public abstract class MixedDomainDeploymentTest {
         }
     }
 
-    private ModelNode executeOnMaster(ModelNode op) throws IOException {
-        return validateResponse(testSupport.getDomainMasterLifecycleUtil().getDomainClient().execute(op));
+    private ModelNode executeOnPrimary(ModelNode op) throws IOException {
+        return validateResponse(testSupport.getDomainPrimaryLifecycleUtil().getDomainClient().execute(op));
     }
 
-    private ModelNode executeOnMaster(Operation op) throws IOException {
-        return validateResponse(testSupport.getDomainMasterLifecycleUtil().getDomainClient().execute(op));
+    private ModelNode executeOnPrimary(Operation op) throws IOException {
+        return validateResponse(testSupport.getDomainPrimaryLifecycleUtil().getDomainClient().execute(op));
     }
 
-    private ModelNode executeForFailureOnMaster(ModelNode op) throws IOException {
-        return validateFailedResponse(testSupport.getDomainMasterLifecycleUtil().getDomainClient().execute(op));
+    private ModelNode executeForFailureOnPrimary(ModelNode op) throws IOException {
+        return validateFailedResponse(testSupport.getDomainPrimaryLifecycleUtil().getDomainClient().execute(op));
     }
 
-    private ModelNode executeForFailureOnMaster(Operation op) throws IOException {
-        return validateFailedResponse(testSupport.getDomainMasterLifecycleUtil().getDomainClient().execute(op));
+    private ModelNode executeForFailureOnPrimary(Operation op) throws IOException {
+        return validateFailedResponse(testSupport.getDomainPrimaryLifecycleUtil().getDomainClient().execute(op));
     }
 
     private ModelNode createDeploymentOperation(ModelNode content, PathAddress... serverGroupAddressses) {
@@ -450,7 +425,7 @@ public abstract class MixedDomainDeploymentTest {
         ModelNode op = createEmptyOperation("read-children-names", address);
         op.get("child-type").set("deployment");
 
-        ModelNode response = testSupport.getDomainMasterLifecycleUtil().getDomainClient().execute(op);
+        ModelNode response = testSupport.getDomainPrimaryLifecycleUtil().getDomainClient().execute(op);
         ModelNode result = validateResponse(response);
         return result.isDefined() ? result.asList() : Collections.<ModelNode>emptyList();
     }
@@ -484,7 +459,7 @@ public abstract class MixedDomainDeploymentTest {
 
     private void removeDeployment(String deploymentName, PathAddress address) throws IOException {
         ModelNode op = createRemoveOperation(address.append(DEPLOYMENT, deploymentName));
-        ModelNode response = testSupport.getDomainMasterLifecycleUtil().getDomainClient().execute(op);
+        ModelNode response = testSupport.getDomainPrimaryLifecycleUtil().getDomainClient().execute(op);
         validateResponse(response);
     }
 }
